=========
Changelog
=========

Version 2.0.4
=============
- Nu statistieken op basis van weighted_sample_statistics
- Force calculate included
- Histograms can now be plotted as well
- Bar width can now be adjusted

Version 1.8.7
=============
- Nu kan je breakdowns ook als combinaties geven. Nodig voor publicatie 2023
- legend default aan plaatjes toegevoegd nu we meerdere jaren hebben
- eval statement kan gebruikt worden om afgeleide kolommen te maken
- dump cache as sqlite optie. Duplicated kolommen worden verwijderd
- bug fix of cache filenaam

Version 1.7.2
=============
- Nu worden zowel mail als web gelezen
- Alle plaatjes voor 2022 publicatie


Version 1.6
===========
- Kan nu met meerdere jaren omgaan

Version 1.5.1
=============

- tex horizontal shift nu platformafhankelijk
- nu ook met normalisatie van pdf
- label % bedrijven hard op % van bedrijven gezet


Version 1.4
===========

- update voor pyscaffold 4

Version 1.3
===========

- Werkende versie voor rapport
